==> rc-ui-lib-0.2.4.tgz: package/es/tabbar/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { Tabbar } from '..';
import { BORDER_TOP_BOTTOM } from '../../utils/constant';
import { sleep, mockGetBoundingClientRect } from '../../../tests/utils'; // const activeClass = 'rc-tabbar-item--active';

describe('Tabbar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should emit change event when click the tabbar item', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, item;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              value: 1,
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "home-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "search"
            }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "friends-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "setting-o"
            }, "\u6807\u7B7E")));
            item = wrapper.find('.rc-tabbar-item');
            _context.next = 5;
            return item.at(0).simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith(0);
            _context.next = 8;
            return item.at(1).simulate('click');

          case 8:
            expect(onChange).toHaveBeenCalledTimes(1);

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should match active tab by name when using name prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var onChange, item;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              value: "a",
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "b"
            }, "Tab")));
            item = wrapper.find('.rc-tabbar-item').at(1);
            _context2.next = 5;
            return item.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith('b'); // expect(item.hasClass(activeClass)).toEqual(true);

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should not render border when border prop is false', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
      border: false,
      value: "a"
    }, /*#__PURE__*/React.createElement(Tabbar.Item, {
      name: "a"
    }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
      name: "b"
    }, "Tab")));
    expect(wrapper.hasClass(BORDER_TOP_BOTTOM)).toEqual(false);
  });
  it('should render placeholder element when using placeholder prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var restore;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            restore = mockGetBoundingClientRect({
              height: 50
            });
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context3.next = 4;
            return sleep(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render cust prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var restore;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            restore = mockGetBoundingClientRect({
              height: 50
            });
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context4.next = 4;
            return sleep(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('render Custom icon correctly', function () {
    var _icon = {
      active: 'https://img.yzcdn.cn/vant/user-active.png',
      inactive: 'https://img.yzcdn.cn/vant/user-inactive.png'
    };
    wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, null, /*#__PURE__*/React.createElement(Tabbar.Item, {
      icon: function icon(ac) {
        return /*#__PURE__*/React.createElement("img", {
          alt: "",
          src: ac ? _icon.active : _icon.inactive
        });
      }
    }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
      icon: "friends-o"
    }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
      icon: "setting-o"
    }, "\u6807\u7B7E")));
    expect(wrapper.html()).toMatchSnapshot();
  });
});

==> rc-ui-lib-0.3.0.tgz: package/es/tabbar/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { Tabbar } from '..';
import { BORDER_TOP_BOTTOM } from '../../utils/constant';
import { sleep } from '../../../tests/utils';
import { mockGetBoundingClientRect } from '../../utils/dom/mock'; // const activeClass = 'rc-tabbar-item--active';

describe('Tabbar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should emit change event when click the tabbar item', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, item;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              value: 1,
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "home-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "search"
            }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "friends-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              icon: "setting-o"
            }, "\u6807\u7B7E")));
            item = wrapper.find('.rc-tabbar-item');
            _context.next = 5;
            return item.at(0).simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith(0);
            _context.next = 8;
            return item.at(1).simulate('click');

          case 8:
            expect(onChange).toHaveBeenCalledTimes(1);

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should match active tab by name when using name prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var onChange, item;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              value: "a",
              onChange: onChange
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "b"
            }, "Tab")));
            item = wrapper.find('.rc-tabbar-item').at(1);
            _context2.next = 5;
            return item.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith('b'); // expect(item.hasClass(activeClass)).toEqual(true);

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should not render border when border prop is false', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
      border: false,
      value: "a"
    }, /*#__PURE__*/React.createElement(Tabbar.Item, {
      name: "a"
    }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
      name: "b"
    }, "Tab")));
    expect(wrapper.hasClass(BORDER_TOP_BOTTOM)).toEqual(false);
  });
  it('should render placeholder element when using placeholder prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var restore;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            restore = mockGetBoundingClientRect({
              height: 50
            });
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context3.next = 4;
            return sleep(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render cust prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var restore;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            restore = mockGetBoundingClientRect({
              height: 50
            });
            wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/React.createElement(Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context4.next = 4;
            return sleep(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('render Custom icon correctly', function () {
    var _icon = {
      active: 'https://img.yzcdn.cn/vant/user-active.png',
      inactive: 'https://img.yzcdn.cn/vant/user-inactive.png'
    };
    wrapper = mount( /*#__PURE__*/React.createElement(Tabbar, null, /*#__PURE__*/React.createElement(Tabbar.Item, {
      icon: function icon(ac) {
        return /*#__PURE__*/React.createElement("img", {
          alt: "",
          src: ac ? _icon.active : _icon.inactive
        });
      }
    }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
      icon: "friends-o"
    }, "\u6807\u7B7E"), /*#__PURE__*/React.createElement(Tabbar.Item, {
      icon: "setting-o"
    }, "\u6807\u7B7E")));
    expect(wrapper.html()).toMatchSnapshot();
  });
});
